Learn R Programming

rewind (version 0.3.0)

rewind_ui: A scrubbable history rail

Description

This function draws the history as a vertical list of steps. The newest step is at the end. The rail shows the current position. A click on a step moves to that step. The rail gets its data from the server. You thus do not have to write a render function.

Usage

rewind_ui(label = "History", max_height = "20rem", class = NULL)

Value

A htmltools::tagList().

Arguments

label

The heading above the rail. Use NULL for no heading.

max_height

The CSS height at which the rail starts to scroll.

class

More CSS classes for the container element.

Examples

Run this code
rewind_ui()
rewind_ui(label = "Steps", max_height = "12rem")

Run the code above in your browser using DataLab